# Muxwell

Muxwell is a command-line tool for managing MKV files and subtitles with batch operations support.

## Installation

Clone the repository

```bash
git clone https://github.com/mdaubie/muxwell.git
```

Install as uv tool

```bash
uv tool install ./muxwell
```
